@@ -1,7 +1,7 @@
 """Parses the command line arguments provided."""
 import argparse
 from textwrap import dedent
-from typing import List, Optional
+from typing import Optional, Sequence
 
 from nbqa import __version__
 from nbqa.text import BOLD, RESET
@@ -31,7 +31,7 @@ USAGE_MSG = dedent(
 )
 
 
-class CLIArgs:  # pylint: disable=R0902
+class CLIArgs:  # pylint: disable=R0902,R0903
     """
     Stores the command line arguments passed.
 
@@ -56,8 +56,8 @@ class CLIArgs:  # pylint: disable=R0902
     """
 
     command: str
-    root_dirs: List[str]
-    nbqa_addopts: List[str]
+    root_dirs: Sequence[str]
+    nbqa_addopts: Sequence[str]
     nbqa_mutate: bool
     nbqa_ignore_cells: Optional[str]
     nbqa_config: Optional[str]
@@ -65,15 +65,15 @@ class CLIArgs:  # pylint: disable=R0902
     nbqa_files: Optional[str]
     nbqa_exclude: Optional[str]
 
-    def __init__(self, args: argparse.Namespace, cmd_args: List[str]) -> None:
+    def __init__(self, args: argparse.Namespace, cmd_args: Sequence[str]) -> None:
         """
         Initialize this instance with the parsed command line arguments.
 
         Parameters
         ----------
-        args (argparse.Namespace):
+        args
             Command line arguments passed to nbqa
-        cmd_args (List[str]):
+        cmd_args
             Additional options to pass to the tool
         """
         self.command = args.command
@@ -86,28 +86,8 @@ class CLIArgs:  # pylint: disable=R0902
         self.nbqa_files = args.nbqa_files or None
         self.nbqa_exclude = args.nbqa_exclude or None
 
-    def __str__(self) -> str:
-        """Return the command from the parsed command line arguments."""
-        args: List[str] = ["nbqa", self.command]
-        args.extend(self.root_dirs)
-        if self.nbqa_mutate:
-            args.append("--nbqa-mutate")
-        if self.nbqa_diff:
-            args.append("--nbqa-diff")
-        if self.nbqa_config:
-            args.append(f"--nbqa-config={self.nbqa_config}")
-        if self.nbqa_ignore_cells:
-            args.append(f"--nbqa-ignore-cells={self.nbqa_ignore_cells}")
-        if self.nbqa_files:
-            args.append(f"--nbqa-files={self.nbqa_files}")
-        if self.nbqa_exclude:
-            args.append(f"--nbqa-exclude={self.nbqa_exclude}")
-        args.extend(self.nbqa_addopts)
-
-        return " ".join(args)
-
     @staticmethod
-    def parse_args(argv: Optional[List[str]]) -> "CLIArgs":
+    def parse_args(argv: Optional[Sequence[str]]) -> "CLIArgs":
         """
         Parse command-line arguments.
 
